@@ -1,5 +1,5 @@
 /*
- * Copyright 2006 Computing Research Labs, New Mexico State University
+ * Copyright 2008 Department of Mathematical Sciences, New Mexico State University
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -14,18 +14,11 @@
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
- * THE COMPUTING RESEARCH LAB OR NEW MEXICO STATE UNIVERSITY BE LIABLE FOR ANY
- * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
- * OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
- * THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+ * DEPARTMENT OF MATHEMATICAL SCIENCES OR NEW MEXICO STATE UNIVERSITY BE
+ * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+ * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+ * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
-#ifndef lint
-#ifdef __GNUC__
-static char svnid[] __attribute__ ((unused)) = "$Id: glyphedit.c 64 2006-09-11 16:39:52Z mleisher $";
-#else
-static char svnid[] = "$Id: glyphedit.c 64 2006-09-11 16:39:52Z mleisher $";
-#endif
-#endif
 
 #include "glyphedit.h"
 #include <gdk/gdk.h>
@@ -340,7 +333,7 @@ glyphedit_draw_focus(GtkWidget *widget, GdkRectangle *area)
      */
     gtk_widget_style_get(widget,
                          "focus-line-width", &fwidth,
-                         "focus-padding", &fpad, (void *) 0);
+                         "focus-padding", &fpad, NULL);
 
     gc = widget->style->bg_gc[GTK_WIDGET_STATE(widget)];
 
@@ -898,7 +891,7 @@ glyphedit_init(GTypeInstance *obj, gpointer g_class)
     gtk_widget_style_get(GTK_WIDGET(gw),
                          "focus-line-width", &fwidth,
                          "focus-padding", &fpad,
-                         (void *) 0);
+                         NULL);
 
     /*
      * Padding that will appear before and after the focus rectangle.
@@ -974,7 +967,7 @@ glyphedit_newv(bdf_glyph_grid_t *grid, guint16 default_pixel_size,
                                  "showXHeight", show_x_height,
                                  "showCapHeight", show_cap_height,
                                  "colorList", colors,
-                                 (void *) 0);
+                                 NULL);
 
     return GTK_WIDGET(ge);
 }
@@ -2414,7 +2407,7 @@ glyphedit_class_init(gpointer g_class, gpointer class_data)
     /*
      * Set the class global variables.
      */
-    parent_class = gtk_type_class(GTK_TYPE_WIDGET);
+    parent_class = g_type_class_peek_parent(g_class);
 
     ocp->destroy = glyphedit_destroy;
 
