@@ -1,5 +1,5 @@
 /*
- * Copyright 2006 Computing Research Labs, New Mexico State University
+ * Copyright 2008 Department of Mathematical Sciences, New Mexico State University
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -14,18 +14,11 @@
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
- * THE COMPUTING RESEARCH LAB OR NEW MEXICO STATE UNIVERSITY BE LIABLE FOR ANY
- * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
- * OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
- * THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+ * DEPARTMENT OF MATHEMATICAL SCIENCES OR NEW MEXICO STATE UNIVERSITY BE
+ * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+ * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+ * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
-#ifndef lint
-#ifdef __GNUC__
-static char svnid[] __attribute__ ((unused)) = "$Id: glyphtest.c 64 2006-09-11 16:39:52Z mleisher $";
-#else
-static char svnid[] = "$Id: glyphtest.c 64 2006-09-11 16:39:52Z mleisher $";
-#endif
-#endif
 
 #include "glyphtest.h"
 
@@ -253,7 +246,7 @@ glyphtest_draw_focus(GtkWidget *widget, GdkRectangle *area)
      */
     gtk_widget_style_get(widget,
                          "focus-line-width", &fwidth,
-                         "focus-padding", &fpad, (void *) 0);
+                         "focus-padding", &fpad, NULL);
 
     gc = widget->style->bg_gc[GTK_WIDGET_STATE(widget)];
 
@@ -540,7 +533,7 @@ glyphtest_class_init(gpointer g_class, gpointer class_data)
     /*
      * Set the class global variables.
      */
-    parent_class = gtk_type_class(GTK_TYPE_WIDGET);
+    parent_class = g_type_class_peek_parent(g_class);
 
     ocp->destroy = glyphtest_destroy;
     gocp->set_property = glyphtest_set_property;
@@ -611,7 +604,7 @@ glyphtest_init(GTypeInstance *obj, gpointer g_class)
      */
     gtk_widget_style_get(GTK_WIDGET(gw),
                          "focus-line-width", &fwidth,
-                         (void *) 0);
+                         NULL);
 
     /*
      * Padding that will appear before and after the focus rectangle.
@@ -663,7 +656,7 @@ glyphtest_get_type(void)
 GtkWidget *
 glyphtest_new(void)
 {
-    return GTK_WIDGET(g_object_new(glyphtest_get_type(), (void *) 0));
+    return GTK_WIDGET(g_object_new(glyphtest_get_type(), NULL));
 }
 
 void
