@@ -1,11 +1,29 @@
 /*
- * $Id: htext.h 67 2006-10-24 13:52:57Z mleisher $
+ * Copyright 2008 Department of Mathematical Sciences, New Mexico State University
+ *
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of this software and associated documentation files (the "Software"),
+ * to deal in the Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ * and/or sell copies of the Software, and to permit persons to whom the
+ * Software is furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
+ * DEPARTMENT OF MATHEMATICAL SCIENCES OR NEW MEXICO STATE UNIVERSITY BE
+ * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+ * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+ * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 static gchar *about_text = ""
 "<help>"
-"<center><b>GBDFEditor 1.2</b>\n"
-"mleisher@crl.nmsu.edu\n"
-"24 October 2006</center>\n"
+"<center><b>GBDFEditor 1.5</b>\n"
+"mleisher@gmail.com\n"
+"06 March 2009</center>\n"
 "\n"
 "GBDFEditor is a BDF font editor that supports "
 "these main features:\n"
@@ -57,19 +75,25 @@ static gchar *program_text = "<help>"
 "<param>-np</param>\t\tdo not pad character cell bitmaps\n"
 "<param>-bp</param>\t\tallow blank pages\n"
 "<param>-ed</param>\t\tno <b>Really Exit?</b> dialog\n"
-"<param>-ps</param> <i>n</i>\tset point size\n"
+"<param>-ps</param> <i>n</i>\t\tset point size\n"
 "<param>-hres</param> <i>n</i>\tset horizontal resolution\n"
 "<param>-vres</param> <i>n</i>\tset vertical resolution\n"
 "<param>-res</param> <i>n</i>\tset both resolutions\n"
-"<param>-sp</param> <i>s</i>\tset the font spacing (<b>p</b>roportional, <b>m</b>onowidth, <b>c</b>haractercell)\n"
+"<param>-sp</param> <i>s</i>\t\tset the font spacing (<b>p</b>roportional, <b>m</b>onowidth, <b>c</b>haractercell)\n"
 "<param>-bpp</param> <i>n</i>\tset the font bits per pixel (<b>1</b>, <b>2</b>, <b>4</b>, <b>8</b>)\n"
 "<param>-eol</param> <i>e</i>\tset the default end of line char(s) (<b>u</b>nix, <b>d</b>os, <b>m</b>ac)\n"
-"<param>-g</param> <i>code</i>\tset the initial glyph code (can be decimal, hex, or octal)\n"
-"<param>-pb</param>\t\tuse watch cursor instead of progress bar\n"
+"<param>-g</param> <i>code</i>\tset the initial glyph code to be displayed at startup(can be decimal, hex, or octal)\n"
 "<param>-cb</param> <i>base</i>\tset the code base for glyph codes (<b>oct</b>, <b>dec</b>, <b>hex</b>)\n"
 "</help>";
 
 static gchar *fgrid_text = "<help>"
+"<center><b>Font Grid</b></center>\n"
+"\n"
+"The main window of each font editor is called the "
+"Font Grid. All of the Font Grids have a special "
+"clipboard used for passing glyphs around. This "
+"clipboard is called <b>FONTGRID_CLIPBOARD</b>.\n"
+"\n"
 "At the top of each editor window there are some "
 "fields and buttons. These are:\n"
 "\n"
@@ -103,11 +127,6 @@ static gchar *fgrid_text = "<help>"
 "the Return key will cause the Font Grid to shift to "
 "the page containing the encoding.</margin>\n"
 "\n"
-"The main window of each font editor is called the "
-"Font Grid. All of the Font Grid's have a special "
-"clipboard used for passing glyphs around. This "
-"clipboard is called <b>FONTGRID_CLIPBOARD</b>.\n"
-"\n"
 "When a glyph has been modified either by the user or "
 "by automatic metrics corrections when the font is loaded, "
 "the glyph code above the glyph cell will be highlighted.\n"
@@ -165,7 +184,7 @@ static gchar *fgrid_text = "<help>"
 "<margin3>During the export, an option menu will let you select whether you "
 "want to:</margin3>\n"
 "\n"
-"<margin3>A. Export the font with it's Unicode mappings.</margin3> "
+"<margin3>A. Export the font with its Unicode mappings.</margin3> "
 " "
 "<margin3>B. Export just the glyphs.</margin3>\n"
 "\n"
@@ -336,19 +355,14 @@ static gchar *fgrid_text = "<help>"
 "glyphs.</margin2>\n"
 "\n"
 "<margin2>To <bi>embolden</bi> means to make bold.</margin2> "
-" "
+"\n\n"
 "<b>Windows</b> "
-"<margin1>New &lt;Ctrl+N&gt;</margin1>\n"
-"<margin2>This will cause a new editor to be created with "
-"the point size, resolution, and bits per pixel "
-"set from the config file, command line, or from "
-"the Setup dialog.</margin2>\n"
 "\n"
 "<margin1>[editor list]</margin1> "
 "<margin2>The remaining menu items are all the Font "
-"Grid's that have been created. Choosing one "
+"Grids that have been created. Choosing one "
 "will force that window to be made visible and "
-"also put that window on top.</margin2>\n"
+"moved to the top.</margin2>\n"
 "\n"
 "<bul>Font Grid Translations</bul>\n"
 "<margin>0..9</margin> "
@@ -536,6 +550,8 @@ static gchar *gedit_text = "<help>"
 "<margin1>Update &lt;Ctrl+S&gt;</margin1> "
 "<margin2>This will update the Font Grid with the "
 "modified glyph.</margin2>\n"
+"<margin1>To the right of the Glyph Name field is a "
+"button that will do this.</margin1>\n"
 "\n"
 "<margin1>Update and Next &lt;Ctrl+U&gt;</margin1> "
 "<margin2>This will update the FontGrid with the "
@@ -580,12 +596,16 @@ static gchar *gedit_text = "<help>"
 "glyph position in the Font Grid. If the "
 "current glyph has been modified, a save prompt "
 "will appear before moving to the next glyph.</margin2>\n"
+"<margin1>To the right of the Glyph Name field is a "
+"button that will do this.</margin1>\n"
 "\n"
 "<margin1>Previous Glyph &lt;Ctrl+P&gt;</margin1> "
 "<margin2>This will move the Glyph Editor to the previous "
 "glyph position in the Font Grid. If the "
 "current glyph has been modified, a save prompt "
 "will appear before moving to the previous glyph.</margin2>\n"
+"<margin1>To the right of the Glyph Name field is a "
+"button that will do this.</margin1>\n"
 "\n"
 "<margin2>If you do not close this editor, it will be updated "
 "with Unicode mappings if you move to the next or "
@@ -817,7 +837,7 @@ static gchar *conf_text = "<help>"
 "\"hexadecimal\".</margin1>\n"
 "\n"
 "<margin>&lt;translation&gt;</margin>\n"
-"<margin1>A &lt;translation&gt; is a valid X Toolkit translation "
+"<margin1>A &lt;translation&gt; is a valid GUI toolkit translation "
 "string.</margin1>\n"
 "\n"
 "<margin>&lt;filename&gt;</margin>\n"
@@ -876,8 +896,8 @@ static gchar *conf_text = "<help>"
 "<margin>close_accelerator_text &lt;labelstring&gt; [default: \"Ctrl+F4\"]</margin>\n"
 "\n"
 "<margin1>The default close accelerator text shown on the "
-"Close/Exit menu options of the FontGrid's and "
-"GlyphEditor's is \"Ctrl+F4\". This option changes the "
+"Close/Exit menu options of the FontGrids and "
+"GlyphEditors is \"Ctrl+F4\". This option changes the "
 "label string on those menu options. This option should "
 "be used in conjunction with the next option.</margin1>\n"
 "\n"
@@ -887,7 +907,7 @@ static gchar *conf_text = "<help>"
 "<margin>close_accelerator &lt;translation&gt; [default: \"&lt;Control&gt;F4\"]</margin>\n"
 "\n"
 "<margin1>The default accelerator for the Close/Exit menu options "
-"in the FontGrid's and GlyphEditor's can sometimes be "
+"in the FontGrids and GlyphEditors can sometimes be "
 "awkward for various reasons. This option allows that "
 "accelerator to be changed. This option should be used "
 "in conjunction with the previous option.</margin1>\n"
@@ -1273,7 +1293,7 @@ static gchar *preferences_text = "<help>"
 "\n"
 "<margin1>The EOL menu sets the end-of-line string used "
 "when BDF fonts are saved. The three most common "
-"options are provided: Unix, DOS, and Mac EOL's.</margin1>\n"
+"options are provided: Unix, DOS, and Mac EOLs.</margin1>\n"
 "\n"
 "<margin>Point Size, Horizontal and Vertical Resolution</margin>\n"
 "\n"
